@@ -1,5 +1,11 @@
+from __future__ import absolute_import
+
 from pyramid_celery.commands import CommandMixin
-from celery.bin.celerybeat import BeatCommand as BaseBeatCommand
+try:
+    from celery.bin.celerybeat import BeatCommand as BaseBeatCommand
+except ImportError:
+    from celery.bin.celery import beat as BaseCeleryCtl
+
 from celery.bin.base import Command
 
 
