@@ -1,18 +1,16 @@
+from __future__ import absolute_import
+
 from pyramid_celery.commands import CommandMixin
-from celery.bin.celeryctl import celeryctl as BaseCeleryCtl
-from celery.bin.celeryctl import help as BaseHelp
-
-
-class Help(BaseHelp):
-    option_list = BaseHelp.option_list[len(BaseCeleryCtl.preload_options):]
+try:
+    from celery.bin.celery import CeleryCommand as BaseCeleryCtl
+except ImportError:
+    from celery.bin.celery import control as BaseCeleryCtl
 
 
 class CeleryCtl(CommandMixin, BaseCeleryCtl):
     commands = BaseCeleryCtl.commands.copy()
-    commands['help'] = Help
     option_list = BaseCeleryCtl.option_list[len(BaseCeleryCtl.preload_options):]
 
 
-
 def main():
     return CeleryCtl().execute_from_commandline()
